package com.chelvc.framework.base.crypto;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.AESUtils;
import com.chelvc.framework.common.util.CodecUtils;
import lombok.NonNull;

/**
 * AES加解密处理实现
 *
 * @author Woody
 * @date 2024/12/27
 */
public class AESCipherHandler implements CipherHandler {
    protected final Cipher encryptor, decrypter;

    public AESCipherHandler(@NonNull String secret) {
        this(AESUtils.ECB_PKCS5PADDING, secret);
    }

    public AESCipherHandler(@NonNull String name, @NonNull String secret) {
        this.encryptor = AESUtils.getEncryptor(name, secret);
        this.decrypter = AESUtils.getDecrypter(name, secret);
    }

    public AESCipherHandler(@NonNull String name, @NonNull String secret, @NonNull String iv) {
        this.encryptor = AESUtils.getEncryptor(name, secret, iv);
        this.decrypter = AESUtils.getDecrypter(name, secret, iv);
    }

    @Override
    public byte[] encrypt(byte[] bytes) {
        return CodecUtils.codec(this.encryptor, bytes);
    }

    @Override
    public byte[] decrypt(byte[] bytes) {
        return CodecUtils.codec(this.decrypter, bytes);
    }
}
