package com.chelvc.framework.security.crypto;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.AESUtils;
import com.chelvc.framework.common.util.CodecUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.security.config.SecurityProperties;
import lombok.NonNull;

/**
 * 数据安全加解密处理默认实现
 *
 * @author Woody
 * @date 2025/1/3
 */
public class DefaultSecurityCipherHandler extends AbstractSecurityCipherHandler implements SecurityCipherHandler {
    protected final Cipher encryptor, decrypter;

    public DefaultSecurityCipherHandler(@NonNull SecurityProperties.Crypto properties) {
        super(properties);
        String name = AESUtils.CBC_PKCS5PADDING, iv = this.str2iv(this.secret);
        this.encryptor = StringUtils.isEmpty(this.secret) ? null : AESUtils.getEncryptor(name, this.secret, iv);
        this.decrypter = StringUtils.isEmpty(this.secret) ? null : AESUtils.getDecrypter(name, this.secret, iv);
    }

    /**
     * 根据字符串获取向量
     *
     * @param str 字符串
     * @return 向量
     */
    private String str2iv(String str) {
        if (StringUtils.isEmpty(str)) {
            return str;
        }
        int size = Math.min(str.length(), 16);
        if (size == 1) {
            return str;
        }
        StringBuilder iv = new StringBuilder(size);
        for (int i = str.length() - 1, max = 0; i >= 0 && max < size; i--, max++) {
            iv.append(str.charAt(i));
        }
        return iv.toString();
    }

    @Override
    public byte[] encrypt(byte[] bytes) {
        return CodecUtils.codec(this.encryptor, bytes);
    }

    @Override
    public byte[] decrypt(byte[] bytes) {
        return CodecUtils.codec(this.decrypter, bytes);
    }
}
