package com.chelvc.framework.security.crypto;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.CodecUtils;
import com.chelvc.framework.security.config.SecurityProperties;
import lombok.NonNull;

/**
 * 动态数据安全加解密处理抽象实现
 *
 * @author Woody
 * @date 2025/1/6
 */
public abstract class DynamicSecurityCipherHandler extends AbstractSecurityCipherHandler
        implements SecurityCipherHandler {
    public DynamicSecurityCipherHandler(@NonNull SecurityProperties.Crypto properties) {
        super(properties);
    }

    /**
     * 获取密码处理器
     *
     * @param mode 加解密模式
     * @return 密码处理器
     */
    protected abstract Cipher getCipher(int mode);

    @Override
    public byte[] encrypt(byte[] bytes) {
        return CodecUtils.codec(this.getCipher(Cipher.ENCRYPT_MODE), bytes);
    }

    @Override
    public byte[] decrypt(byte[] bytes) {
        return CodecUtils.codec(this.getCipher(Cipher.DECRYPT_MODE), bytes);
    }
}
